from setuptools import setup, find_packages

setup(
    name='ashok-ll',  
    version='0.1.2',
    author='Ashok Bongu',
    author_email='bonguashok86@example.com',
    description='A Python package for Linked List operations by Ashok',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    packages=find_packages(),  
    install_requires=[],
    python_requires='>=3.6',
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
)



from .node import ListNode 

def reverseLL(head : ListNode) -> ListNode :
    prev = None 
    temp = head 
    while temp :
        front = temp.next
        temp.next = prev 
        prev = temp 
        temp = front
    return prev

def printLL(head : ListNode) -> None :
    temp = head 
    while temp :
        print(temp.val , end=" -> ")
        temp = temp.next
    print("NULL")

def deleteHead(head : ListNode) -> ListNode :
    if head == None or head.next == None:
        return None
    return head.next


# pypi-AgEIcHlwaS5vcmcCJGFmZWMyNzBhLTg1NDUtNGQxYy05MGFhLWRlNjgyNTgwMTI2NwACKlszLCI1Yzc0MGM5OS05YWI4LTQ0MTYtYWE3My1hNzg4NWQwOTg0NzIiXQAABiCqeVEPaWx4DhYlQq260_HTIlpeOGAI7UG7fADVeks2SA